@@ -7,7 +7,8 @@ int Dice::instances = 0;
  *
  * @fn Dice
  */
-Dice::Dice()
+Dice::Dice(QObject *parent) :
+        QObject(parent)
 {
     ++instances;
     qDebug() << "Dice instances:" << instances;
@@ -21,7 +22,6 @@ Dice::Dice()
 Dice::~Dice()
 {
     --instances;
-    slotClearDie();
     qDebug() << "Dice instances left:" << instances;
 }
 
@@ -44,28 +44,29 @@ QVector<Die* > const& Dice::getDice() const
  */
 void Dice::slotAddDie(int eyes)
 {
-    Die* die = new Die(eyes);
+    // Die with this as parent ensure that the Die object will be deleted as soon as this
+    // is deleted.
+    Die* die = new Die(eyes, this);
     dice.append(die);
     emit signalDieAdded(die);
 }
 
 /**
- * Remove all dice from the heap and Collection.
+ * Remove all dice from the Collection.
  *
  * @fn slotClearDie
  */
 void Dice::slotClearDie()
 {
     qDebug() << "Clear die";
-    foreach(Die * die, dice)
-    {
-        slotRemoveDie(die);
-    }
+    // No need to worry about deletion of Die objects from memory. It will be taken care of
+    // when this instance is deleted.
+    dice.clear();
     emit signalDieCleared();
 }
 
 /**
- * Remove the given die from the heap and Collection.
+ * Remove the given die from the Collection.
  *
  * @fn slotRemoveDie
  * @param Die * die - pointer to the Die object to be removed.
@@ -74,6 +75,5 @@ void Dice::slotRemoveDie(Die * die)
 {
     qDebug() << "Remove die:" << die->getEyes();
     dice.remove(dice.indexOf(die));
-    delete die;
     emit signalDieRemoved();
 }
