@@ -13,7 +13,7 @@ private:
     static int instances;
     QVector <Die* > dice;
 public:
-    Dice();
+    explicit Dice(QObject *parent = 0);
     virtual ~Dice();
     QVector<Die* > const& getDice() const;
 
