@@ -14,8 +14,7 @@ private:
     int eyes;
     int randomToken;
 public:
-
-    Die(int eyes);
+    explicit Die(int eyes, QObject *parent = 0);
     virtual ~Die();
     void setEyes(int eyes);
     int getEyes() const;
