@@ -5,7 +5,9 @@
 #include <QMainWindow>
 #include <QMessageBox>
 #include <QSettings>
+#include <QAccelerometerReading>
 #include "dice.h"
+#include "accelerometerpoller.h"
 
 namespace Ui {
     class MainWindow;
@@ -19,18 +21,30 @@ public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
+    void initSensor();
+
 private:
     QSettings *settings;
+    AccelerometerPoller * accelerometerPoller;
     bool landscape;
 
+    qreal previousX;
+    qreal previousY;
+    qreal previousZ;
+
     Ui::MainWindow *ui;
     Dice dice;
 
+    void startAccelerometer();
+    void stopAccelerometer();
+
 public slots:
     void slotDieAdded(Die const* die);
     void slotDiceCleared();
+    void slotSensorReading(QAccelerometerReading * reading);
 
 private slots:
+    void on_actionShake_triggered();
     void on_actionRotate_triggered();
     void on_throwDicePushButton_clicked();
     void on_clearDicePushButton_clicked();
